#!/bin/sh
# Licensed Materials - Property of IBM
# 5648-F10 (C) Copyright International Business Machines Corp. 2005 
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.

# traps the SIGTTOU command that might be thrown if the user invokes
# ./launchpad.sh &
trap '' 22
    
    supportedMozillaVersion() {
	case "$*" in
	    *rv:1.[7-9]*) return 0;;
	    *rv:[2-9].[0-9]*) return 0;;
	    *rv:*) return 1;;
	    Mozilla\ 1.[7-9]*) return 0;;
	    Mozilla\ [2-9].[0-9]*) return 0;;
	    *) return 1;;
	esac
    }

    supportedFirefoxVersion() {
	case "$*" in
            *Firefox\ [1-9].*) return 0;;
	    *Firefox/[1-9].*) return 0;;
            *Firefox*) return 1;;
            *rv:1.[7-9]*) return 0;;
            *rv:[2-9].*) return 0;;
	    *rv:*) return 1;;
	    Mozilla*\ 1.[7-9]*) return 0;;
	    Mozilla*\ [2-9].[0-9]*) return 0;;
	    *) return 1;;
	esac
    }

    whichBrowser=NoBrowser
    case "$0" in
        /*) fullpath=$0;;
         *) fullpath=`pwd`/$0;;
    esac
    installsourcepath=`echo "$fullpath" | sed "s,/\./,/,g; s,/[^/][^/]*/\.\./,/,g; s,//,/,g; s,/[^/]*$,,"`

    if [ -z "$LaunchPadContentDir" ]; then
        LaunchPadContentDir=content/
        export LaunchPadContentDir
    fi
    
    # Added for RTC Launchpad:
    LaunchpadUserId=`id -u`
    export LaunchpadUserId

    #cross platform way to see if the launchpadEnv file exists (-e doesn't work on solaris)
    ls "$installsourcepath/launchpad/launchpadEnv" > /dev/null 2>&1 
    if [ $? -eq 0 ]; then    
        #while read k v; eval $k=$v; export $k; done < "$installsourcepath/launchpad/launchpadEnv"
	while read key value
	do
	  #don't set variables that are already defined	
	  if [ "$key" ]; then
	    #Ensure the line is somewhat well formed by checking that a value is also specified	    
	    if [ "$value" ];  then	  
	      eval $key=$value
	      export $key
	    fi
	  fi
        done < $installsourcepath/launchpad/launchpadEnv		
    fi

    #If BROWSER isn't set, check LaunchPadDefaultBrowser
    if [ -z "$BROWSER" ]; then
      if [ "$LaunchPadDefaultBrowser" ]; then 
        #First see if LaunchPadDefaultBrowser needs to be translated from one of the supported values
        if [ $LaunchPadDefaultBrowser = "MozillaHTML" ]; then
	  LaunchPadDefaultBrowser=mozilla;
	fi
	if [ $LaunchPadDefaultBrowser = "Mozilla" ]; then
	  LaunchPadDefaultBrowser=mozilla;
	fi
	if [ $LaunchPadDefaultBrowser = "FirefoxHTML" ]; then
	  LaunchPadDefaultBrowser=firefox;
	fi
	if [ $LaunchPadDefaultBrowser = "Firefox" ]; then
	  LaunchPadDefaultBrowser=firefox;
	fi
	#Finally, set the browser
        BROWSER=$LaunchPadDefaultBrowser; export BROWSER;
      fi
    fi

    if [ "$BROWSER" ]; then
        if versionString=`($BROWSER -version) 2>/dev/null`; then
            case "$versionString" in
	    *Firefox*) if supportedFirefoxVersion "$versionString"; then
               	           whichBrowser=Firefox
           	       fi ;;
	    *Mozilla*) if supportedMozillaVersion "$versionString"; then
               	           whichBrowser=Mozilla
           	       fi ;;
            esac
        fi
    fi
    if [ $whichBrowser = NoBrowser ]; then
	PATH="$PATH:/usr/X11R6/bin:/usr/local/bin:/usr/bin:/opt/mozilla:/usr/mozilla:/usr/mozilla/sfw/lib/mozilla"
        if versionString=`(mozilla -version) 2>/dev/null`; then
	    BROWSER=mozilla; export BROWSER
	    if supportedMozillaVersion "$versionString"; then
		whichBrowser=Mozilla
	    fi
	fi
    fi
    if [ $whichBrowser = NoBrowser ]; then
	PATH="$PATH:/opt/firefox:/usr/firefox:/usr/firefox/sfw/lib/firefox"
        if versionString=`(firefox -version) 2>/dev/null`; then
	    BROWSER=firefox; export BROWSER
	    if supportedFirefoxVersion "$versionString"; then
		whichBrowser=Firefox
	    fi
	fi
    fi
    
    
    LaunchPadArch=`$installsourcepath/launchpad/SetArchitecture.sh`
    export LaunchPadArch
    
    # Changed for RTC Launchpad:
    exec $installsourcepath/launchpad/$whichBrowser.sh
    # eval $* exec $installsourcepath/launchpad/$whichBrowser.sh
    